Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3673)

Unified Diff: chrome/browser/browser_about_handler.h

Issue 7064052: Revert 88142 to fix sync_integration_tests offline. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/browser_about_handler.h
===================================================================
--- chrome/browser/browser_about_handler.h (revision 88158)
+++ chrome/browser/browser_about_handler.h (working copy)
@@ -19,21 +19,25 @@
class GURL;
class Profile;
-// Returns true if the given URL will be handled by the browser about handler.
-// |url| should have been processed by URLFixerUpper::FixupURL, which replaces
-// the about: scheme with chrome:// for all about:foo URLs except "about:blank".
-// Some |url| host values will be replaced with their respective redirects.
+// Decides whether the given URL will be handled by the browser about handler
+// and returns true if so. On true, it may also modify the given URL to be the
+// final form (we fix up most "about:" URLs to be "chrome:" because WebKit
+// handles all "about:" URLs as "about:blank.
//
// This is used by BrowserURLHandler.
bool WillHandleBrowserAboutURL(GURL* url, Profile* profile);
+// Register the data source for chrome://about URLs.
+// Safe to call multiple times.
+void InitializeAboutDataSource(Profile* profile);
+
// We have a few magic commands that don't cause navigations, but rather pop up
// dialogs. This function handles those cases, and returns true if so. In this
// case, normal tab navigation should be skipped.
bool HandleNonNavigationAboutURL(const GURL& url);
-// Gets the paths that are shown in chrome://chrome-urls.
-std::vector<std::string> ChromePaths();
+// Gets the paths that are shown in about:about.
+std::vector<std::string> AboutPaths();
#if defined(USE_TCMALLOC)
// A map of header strings (e.g. "Browser", "Renderer PID 123")
« no previous file with comments | « chrome/browser/automation/automation_tab_helper_browsertest.cc ('k') | chrome/browser/browser_about_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698